@@ -11,6 +11,7 @@ from matplotlib.colorbar import Colorbar
 from matplotlib.colors import Colormap, LogNorm, Normalize
 from matplotlib.dates import date2num
 from matplotlib.figure import Figure, SubFigure
+from matplotlib.legend import Legend
 from matplotlib.offsetbox import AnchoredOffsetbox, AnchoredText
 from matplotlib.text import Text
 from numpy.typing import ArrayLike, NDArray
@@ -46,8 +47,9 @@ from ...utils.time import (
     validate_time_range,
 )
 from ...utils.typing import DistanceRangeLike, ValueRangeLike, validate_numeric_range
-from ..color import Cmap, Color, get_cmap
+from ..color import Cmap, Color, ColorLike, get_cmap
 from ..save import save_plot
+from ..text import shade_around_text
 from .along_track import AlongTrackAxisStyle, format_along_track_axis
 from .annotation import (
     add_text,
@@ -219,6 +221,10 @@ class CurtainFigure:
         else:
             self.min_num_profiles = 1000
 
+        self.legend: Legend | None = self.ax.get_legend()
+        self._legend_handles: list = []
+        self._legend_labels: list = []
+
     def _set_info_text_loc(self, info_text_loc: str | None) -> None:
         if isinstance(info_text_loc, str):
             self.info_text_loc = info_text_loc
@@ -339,6 +345,7 @@ class CurtainFigure:
         ) = None,
         mark_profiles_at_linestyle: str | Sequence[str] = "solid",
         mark_profiles_at_linewidth: float | Sequence[float] = 2.5,
+        label_length: int = 40,
         **kwargs,
     ) -> "CurtainFigure":
         # Parse colors
@@ -525,7 +532,7 @@ class CurtainFigure:
                     if height_range[i] is None:
                         height_range[i] = np.atleast_2d(vp.height)[0, i]
                     height_range = tuple(height_range)
-            vp = vp.select_height_range(height_range)
+            vp = vp.select_height_range(height_range, pad_idx=1)
         else:
             height_range = (
                 np.atleast_2d(vp.height)[0, 0],
@@ -587,7 +594,7 @@ class CurtainFigure:
                     fig=self.fig,
                     ax=self.ax,
                     data=mesh,
-                    label=format_var_label(vp.label, vp.units),
+                    label=format_var_label(vp.label, vp.units, label_len=label_length),
                     cmap=cmap,
                 )
             else:
@@ -595,7 +602,7 @@ class CurtainFigure:
                     fig=self.fig,
                     ax=self.ax,
                     data=mesh,
-                    label=format_var_label(vp.label, vp.units),
+                    label=format_var_label(vp.label, vp.units, label_len=label_length),
                     ticks=colorbar_ticks,
                     tick_labels=colorbar_tick_labels,
                 )
@@ -741,6 +748,7 @@ class CurtainFigure:
         ) = None,
         mark_profiles_at_linestyle: str | Sequence[str] = "solid",
         mark_profiles_at_linewidth: float | Sequence[float] = 2.5,
+        label_length: int = 40,
         **kwargs,
     ) -> "CurtainFigure":
         """Plot a vertical curtain (i.e. cross-section) of a variable along the satellite track a EarthCARE dataset.
@@ -943,6 +951,7 @@ class CurtainFigure:
         marker: str | None = None,
         markersize: int | float | None = None,
         fill: bool = False,
+        legend_label: str | None = None,
     ) -> "CurtainFigure":
         """Adds height line to the plot."""
         color = Color.from_optional(color)
@@ -952,16 +961,22 @@ class CurtainFigure:
 
         hnew, tnew = _convert_height_line_to_time_bin_step_function(height, time)
 
+        fb: list = []
         if fill:
-            self.ax.fill_between(
+            _fb1 = self.ax.fill_between(
                 tnew,
                 hnew,
                 color=color,
                 alpha=alpha,
                 zorder=zorder,
             )
+            from matplotlib.patches import Patch
 
-        self.ax.plot(
+            # Proxy for the legend
+            _fb2 = Patch(facecolor=color, alpha=alpha, linewidth=0.0)
+            fb = [_fb1, _fb2]
+
+        hl = self.ax.plot(
             tnew,
             hnew,
             linestyle=linestyle,
@@ -973,6 +988,10 @@ class CurtainFigure:
             zorder=zorder,
         )
 
+        if isinstance(legend_label, str):
+            self._legend_handles.append(tuple(hl + fb))
+            self._legend_labels.append(legend_label)
+
         return self
 
     def ecplot_height(
@@ -988,6 +1007,7 @@ class CurtainFigure:
         markersize: int | float | None = 1,
         show_info: bool = True,
         info_text_loc: str | None = None,
+        legend_label: str | None = None,
     ) -> "CurtainFigure":
         """Adds height line to the plot."""
         height = ds[var].values
@@ -1001,6 +1021,7 @@ class CurtainFigure:
             zorder=zorder,
             marker=marker,
             markersize=markersize,
+            legend_label=legend_label,
         )
 
         self._set_info_text_loc(info_text_loc)
@@ -1090,10 +1111,10 @@ class CurtainFigure:
         hatch: str = "/////",
         linewidth: float = 1,
         linewidth_border: float = 0,
-        color: Color | str | list | NDArray | None = "black",
-        color_border: Color | str | list | NDArray | None = None,
+        color: ColorLike | None = "black",
+        color_border: ColorLike | None = None,
         zorder: int | float | None = 2,
-        label: str | None = None,
+        legend_label: str | None = None,
     ) -> "CurtainFigure":
         """Adds hatched/filled areas to the plot."""
         values = np.asarray(values)
@@ -1124,7 +1145,7 @@ class CurtainFigure:
         cnf.set_color(color_border)  # type: ignore
         cnf.set_linewidth(linewidth_border)
 
-        if isinstance(label, str) and len(label) > 0:
+        if isinstance(legend_label, str):
             from matplotlib.patches import Patch
 
             _facecolor = "none"
@@ -1136,27 +1157,11 @@ class CurtainFigure:
                 facecolor=_facecolor,
                 edgecolor=color.hex,
                 hatch=hatch,
-                label=label,
+                label=legend_label,
             )
 
-            if self.ax.get_legend() is not None:
-                handles = [
-                    h for h in self.ax.get_legend().legend_handles if h is not None
-                ]
-            else:
-                handles = []
-            labels = [h.get_label() for h in handles]
-
-            handles.append(hatch_patch)
-            labels.append(hatch_patch.get_label())
-
-            self.ax.legend(
-                handles=handles,
-                labels=labels,
-                loc="upper right",
-                bbox_to_anchor=(1.0, -0.12),
-                frameon=False,
-            )
+            self._legend_handles.append(hatch_patch)
+            self._legend_labels.append(legend_label)
 
         return self
 
@@ -1170,10 +1175,10 @@ class CurtainFigure:
         hatch: str = "/////",
         linewidth: float = 1,
         linewidth_border: float = 0,
-        color: Color | str | list | NDArray | None = "black",
-        color_border: Color | str | list | NDArray | None = None,
+        color: ColorLike | None = "black",
+        color_border: ColorLike | None = None,
         zorder: int | float | None = 2,
-        label: str | None = None,
+        legend_label: str | None = None,
     ) -> "CurtainFigure":
         """Adds hatched/filled areas to the plot."""
         height = ds[height_var].values
@@ -1191,7 +1196,7 @@ class CurtainFigure:
             color=color,
             color_border=color_border,
             zorder=zorder,
-            label=label,
+            legend_label=legend_label,
         )
 
     def ecplot_hatch_attenuated(
@@ -1281,6 +1286,7 @@ class CurtainFigure:
         var: str = ELEVATION_VAR,
         time_var: str = TIME_VAR,
         color: Color | str | None = "ec:elevation",
+        legend_label: str | None = None,
     ) -> "CurtainFigure":
         """Adds filled elevation/surface area to the plot."""
         height = ds[var].values
@@ -1295,6 +1301,7 @@ class CurtainFigure:
             markersize=0,
             fill=True,
             zorder=10,
+            legend_label=legend_label,
         )
         return self
 
@@ -1306,6 +1313,7 @@ class CurtainFigure:
         color: Color | str | None = "ec:tropopause",
         linewidth: float = 2,
         linestyle: str = "solid",
+        legend_label: str | None = None,
     ) -> "CurtainFigure":
         """Adds tropopause line to the plot."""
         height = ds[var].values
@@ -1320,6 +1328,7 @@ class CurtainFigure:
             markersize=0,
             fill=False,
             zorder=12,
+            legend_label=legend_label,
         )
 
         return self
@@ -1346,6 +1355,12 @@ class CurtainFigure:
         # Remove colorbar
         if self.colorbar:
             self.colorbar.remove()
+            self.colorbar = None
+
+        # Remove legend
+        if self.legend:
+            self.legend.remove()
+            self.legend = None
 
         return self
 
@@ -1363,6 +1378,66 @@ class CurtainFigure:
             self.ax_right.invert_yaxis()
         return self
 
+    def show_legend(
+        self,
+        loc: str = "upper left",
+        markerscale: float = 1.5,
+        frameon: bool = True,
+        facecolor: ColorLike = "white",
+        edgecolor: ColorLike = "black",
+        framealpha: float = 0.8,
+        edgewidth: float = 1.5,
+        fancybox: bool = False,
+        handlelength: float = 0.7,
+        handletextpad: float = 0.5,
+        borderaxespad: float = 0,
+        ncols: int = 8,
+        textcolor: ColorLike = "black",
+        textweight: int | str = "normal",
+        textshadealpha: float = 0.0,
+        textshadewidth: float = 3.0,
+        textshadecolor: ColorLike = "white",
+        **kwargs,
+    ) -> "CurtainFigure":
+        from matplotlib.legend_handler import HandlerTuple
+
+        facecolor = Color(facecolor)
+        edgecolor = Color(edgecolor)
+        textcolor = Color(textcolor)
+        textshadecolor = Color(textshadecolor)
+
+        if len(self._legend_handles) > 0:
+            self.legend = self.ax.legend(
+                self._legend_handles,
+                self._legend_labels,
+                loc=loc,
+                markerscale=markerscale,
+                frameon=frameon,
+                facecolor=facecolor,
+                edgecolor=edgecolor,
+                framealpha=framealpha,
+                fancybox=fancybox,
+                handlelength=handlelength,
+                handletextpad=handletextpad,
+                borderaxespad=borderaxespad,
+                ncols=ncols,
+                handler_map={tuple: HandlerTuple(ndivide=1)},
+                **kwargs,
+            )
+            self.legend.get_frame().set_linewidth(edgewidth)
+            for text in self.legend.get_texts():
+                text.set_color(textcolor)
+                text.set_fontweight(textweight)
+
+                if textshadealpha > 0:
+                    text = shade_around_text(
+                        text,
+                        alpha=textshadealpha,
+                        linewidth=textshadewidth,
+                        color=textshadecolor,
+                    )
+        return self
+
     def show(self):
         self.fig.tight_layout()
         self.fig.show()
